==> RASClient_Basic-x64-20.2.26020.zip: AppServerClientCLIhelpMD/startrasobj.md <==


![Parralels](https://www.parallels.com/static/pl/fileadmin/res/img/navigation/pl-logo-dk.png)

# AppserverClient Command Line Interface

## startrasobj

starts a published object from a RAS connection.

**Category: RAS-Connections**


```
AppServerClientCLI startrasobj -id ras:61:34 [-waitforid [20]] [-dismisserrortime 5][returnpath]
```
* **` id (mandatory) `** Specify the published item ID to use.
* **` waitforid (optional) `** Wait for sessionid then return it. See notes for further information. Has no effect on local applications.
* **` dismisserrortime (optional) `** Time in seconds before the error message is automatically dismissed. A value of -1 will not show the error. Has no effect on local applications.
* **` returnpath (optional) `** When set, the command will return the arguments required to start the application instead of starting it.
## Return codes:
  ok
  NotAvailable
  InvalidId
  InvalidArgs
  Exception
## Examples:
  AppServerClientCLI startrasobj -id ras:61:34
  AppServerClientCLI startrasobj -id ras:61:34 -waitforid
  AppServerClientCLI startrasobj -id ras:61:34 -waitforid 20
## Notes:
  If you use waitforid, the CLI will wait until the session is started and its ID is returned. waitforid can take the time in seconds after which the command would timeout as an argument.
## See also:
[logonras](logonras.md)
[logoffras](logoffras.md)
[logoffallras](logoffallras.md)
[logoffrassession](logoffrassession.md)
[savefavorites](savefavorites.md)
[disconnectras](disconnectras.md)
[disconnectallras](disconnectallras.md)
[getloggedrasinfo](getloggedrasinfo.md)
[getraspolicyinfo](getraspolicyinfo.md)

==> RASClient_Basic-x64-21.0.26250.zip: AppServerClientCLIhelpMD/startrasobj.md <==


![Parralels](https://www.parallels.com/static/pl/fileadmin/res/img/navigation/pl-logo-dk.png)

# AppserverClient Command Line Interface

## startrasobj

starts a published object from a RAS connection.

**Category: RAS-Connections**




```  
AppServerClientCLI startrasobj -id ras:61:34 [-waitforid [20]] [-dismisserrortime 5] [returnpath] [-window 12345]  
```
## Arguments  
* **` id (mandatory) `** Specify the published item ID to use.  
* **` waitforid (optional) `** Wait for sessionid then return it. See notes for further information. Has no effect on local applications.  
* **` dismisserrortime (optional) `** Time in seconds before the error message is automatically dismissed. A value of -1 will not show the error. Has no effect on local applications.  
* **` returnpath (optional) `** When set, the command will return the arguments required to start the application instead of starting it.  
* **` window (optional) `** Specify the window handle that will be used as the parent to any UI required.

## Return codes:  
  ok - Command was successful  
  NotAvailable - Communication with the client backend failed, ensure that the client is running  
  InvalidId - Invalid connection, object or session ID  
  InvalidArgs - Some arguments are missing or invalid  
  Exception - System problem

## Examples:  
  AppServerClientCLI startrasobj -id ras:61:34  
  AppServerClientCLI startrasobj -id ras:61:34 -waitforid  
  AppServerClientCLI startrasobj -id ras:61:34 -waitforid 20

## Notes:  
  If you use waitforid, the CLI will wait until the session is started and its ID is returned. waitforid can take the time in seconds after which the command would timeout as an argument.

## See also:  
[logonras](logonras.md)    
[logoffras](logoffras.md)    
[logoffallras](logoffallras.md)    
[logoffrassession](logoffrassession.md)    
[savefavorites](savefavorites.md)    
[disconnectras](disconnectras.md)    
[disconnectallras](disconnectallras.md)    
[getloggedrasinfo](getloggedrasinfo.md)    
[getraspolicyinfo](getraspolicyinfo.md)    
[getpublicipinfo](getpublicipinfo.md)    
[clearpublicipinfo](clearpublicipinfo.md)
